@@ -34,7 +34,7 @@ class TerracompProfile:
 
 def load_config(filename: Path = DEFAULT_CONFIG_FILE) -> TerracompConfig:
     raw_data = yaml.safe_load(filename.read_text())
-    return databind.jons.load(raw_data, TerracompConfig)
+    return databind.json.load(raw_data, TerracompConfig)
 
 
 def save_config(config: TerracompConfig, filename: Path = DEFAULT_CONFIG_FILE) -> None:
